#!/usr/bin/env python3

from ._bonferroni_correction import bonferroni_correction
from ._brunner_munzel_test import brunner_munzel_test
from ._multicompair import multicompair
from ._nocorrelation_test import nocorrelation_test
from ._calc_partial_corr import calc_partial_corr
from ._fdr_correction import fdr_correction, fdr_correction_torch
